EXPORTS
	?AppendClearSeenL@CImapFolder@@QAEXK@Z @ 1 NONAME ; void CImapFolder::AppendClearSeenL(unsigned long)
	?AppendSetSeenL@CImapFolder@@QAEXK@Z @ 2 NONAME ; void CImapFolder::AppendSetSeenL(unsigned long)
	?CancelForMigrate@CImapSyncManager@@QAEXXZ @ 3 NONAME ; void CImapSyncManager::CancelForMigrate(void)
	?Changed@CImapFolder@@QAEHAAVCImapSession@@@Z @ 4 NONAME ; int CImapFolder::Changed(class CImapSession &)
	?DeleteFolderContentsL@CImapSyncManager@@QAEXJ@Z @ 5 NONAME ; void CImapSyncManager::DeleteFolderContentsL(long)
	?DeleteMessageL@CImapFolder@@QAEXJ@Z @ 6 NONAME ; void CImapFolder::DeleteMessageL(long)
	?DoQuoteL@CImapFolder@@SAXAAPAVHBufC16@@@Z @ 7 NONAME ; void CImapFolder::DoQuoteL(class HBufC16 * &)
	?ExamineL@CImapFolder@@QAEXAAVTRequestStatus@@AAVCImapSession@@@Z @ 8 NONAME ; void CImapFolder::ExamineL(class TRequestStatus &, class CImapSession &)
	?FullFolderPathL@CImapFolder@@QAEAAVTDesC16@@XZ @ 9 NONAME ; class TDesC16 & CImapFolder::FullFolderPathL(void)
	?GetFetchMessageChildrenL@CImapFolder@@QAEHAAVCMsvEntrySelection@@@Z @ 10 NONAME ; int CImapFolder::GetFetchMessageChildrenL(class CMsvEntrySelection &)
	?GetFolderL@CImapSyncManager@@QAEPAVCImapFolder@@JH@Z @ 11 NONAME ; class CImapFolder * CImapSyncManager::GetFolderL(long, int)
	?GetSubscribedFolder@CImapSyncManager@@QAEPAVCImapFolder@@JAAJ@Z @ 12 NONAME ; class CImapFolder * CImapSyncManager::GetSubscribedFolder(long, long &)
	?GetTempFolderL@CImapSyncManager@@QAEPAVCImapFolder@@J@Z @ 13 NONAME ; class CImapFolder * CImapSyncManager::GetTempFolderL(long)
	?Inbox@CImapSyncManager@@QAEPAVCImapFolder@@XZ @ 14 NONAME ; class CImapFolder * CImapSyncManager::Inbox(void)
	?MailboxId@CImapFolder@@QAEJXZ @ 15 NONAME ; long CImapFolder::MailboxId(void)
	?MakePathL@CImapFolder@@QAEPAVHBufC16@@H@Z @ 16 NONAME ; class HBufC16 * CImapFolder::MakePathL(int)
	?NewL@CImapFolder@@SAPAV1@AAVCImapSyncManager@@AAVCMsvServerEntry@@AAVTMsvEmailEntry@@AAVCImapSettings@@ABVTDesC16@@@Z @ 17 NONAME ; class CImapFolder * CImapFolder::NewL(class CImapSyncManager &, class CMsvServerEntry &, class TMsvEmailEntry &, class CImapSettings &, class TDesC16 const &)
	?NewL@CImapSyncManager@@SAPAV1@AAVCMsvServerEntry@@AAVCImapSettings@@@Z @ 18 NONAME ; class CImapSyncManager * CImapSyncManager::NewL(class CMsvServerEntry &, class CImapSettings &)
	?NewLC@CImapFolder@@SAPAV1@AAVCImapSyncManager@@AAVCMsvServerEntry@@AAVTMsvEmailEntry@@AAVCImapSettings@@ABVTDesC16@@@Z @ 19 NONAME ; class CImapFolder * CImapFolder::NewLC(class CImapSyncManager &, class CMsvServerEntry &, class TMsvEmailEntry &, class CImapSettings &, class TDesC16 const &)
	?NewLC@CImapSyncManager@@SAPAV1@AAVCMsvServerEntry@@AAVCImapSettings@@@Z @ 20 NONAME ; class CImapSyncManager * CImapSyncManager::NewLC(class CMsvServerEntry &, class CImapSettings &)
	?NextSubscribedFoldersL@CImapSyncManager@@QAEXAAJ@Z @ 21 NONAME ; void CImapSyncManager::NextSubscribedFoldersL(long &)
	?Progress@CImapFolder@@QAEXAAVTImap4SyncProgress@@@Z @ 22 NONAME ; void CImapFolder::Progress(class TImap4SyncProgress &)
	?Progress@CImapSyncManager@@QAEXAAVTImap4SyncProgress@@@Z @ 23 NONAME ; void CImapSyncManager::Progress(class TImap4SyncProgress &)
	?RemoveFolderL@CImapSyncManager@@QAEXJ@Z @ 24 NONAME ; void CImapSyncManager::RemoveFolderL(long)
	?RenameLocalL@CImapSyncManager@@QAEXJABVTDesC16@@@Z @ 25 NONAME ; void CImapSyncManager::RenameLocalL(long, class TDesC16 const &)
	?ResetInboxClearNewFlags@CImapSyncManager@@QAEXXZ @ 26 NONAME ; void CImapSyncManager::ResetInboxClearNewFlags(void)
	?ResetNonInboxClearNewFlags@CImapSyncManager@@QAEXXZ @ 27 NONAME ; void CImapSyncManager::ResetNonInboxClearNewFlags(void)
	?SelectL@CImapFolder@@QAEXAAVTRequestStatus@@AAVCImapSession@@H@Z @ 28 NONAME ; void CImapFolder::SelectL(class TRequestStatus &, class CImapSession &, int)
	?SyncDeletesL@CImapFolder@@QAEXAAVTRequestStatus@@AAVCImapSession@@@Z @ 29 NONAME ; void CImapFolder::SyncDeletesL(class TRequestStatus &, class CImapSession &)
	?SynchroniseDeletesL@CImapSyncManager@@QAEXAAVTRequestStatus@@AAVCImapSession@@@Z @ 30 NONAME ; void CImapSyncManager::SynchroniseDeletesL(class TRequestStatus &, class CImapSession &)
	?SynchroniseFolderSubscriptionsL@CImapSyncManager@@QAEXAAVTRequestStatus@@AAVCImapSession@@@Z @ 31 NONAME ; void CImapSyncManager::SynchroniseFolderSubscriptionsL(class TRequestStatus &, class CImapSession &)
	?SynchroniseFolderTreeL@CImapSyncManager@@QAEXAAVTRequestStatus@@AAVCImapSession@@@Z @ 32 NONAME ; void CImapSyncManager::SynchroniseFolderTreeL(class TRequestStatus &, class CImapSession &)
	?SynchroniseInboxL@CImapSyncManager@@QAEXAAVTRequestStatus@@AAVCImapSession@@@Z @ 33 NONAME ; void CImapSyncManager::SynchroniseInboxL(class TRequestStatus &, class CImapSession &)
	?SynchroniseL@CImapFolder@@QAEXAAVTRequestStatus@@AAVCImapSession@@HH@Z @ 34 NONAME ; void CImapFolder::SynchroniseL(class TRequestStatus &, class CImapSession &, int, int)
	?SynchroniseSubscribedFoldersL@CImapSyncManager@@QAEXAAVTRequestStatus@@AAVCImapSession@@AAJ@Z @ 35 NONAME ; void CImapSyncManager::SynchroniseSubscribedFoldersL(class TRequestStatus &, class CImapSession &, long &)
	?UpdateSessionFolderInfoL@CImapFolder@@QAEXAAVCImapSession@@@Z @ 36 NONAME ; void CImapFolder::UpdateSessionFolderInfoL(class CImapSession &)

